@@ -16,6 +16,8 @@ p a c k a g e   P O E : : C o m p o n e n t : : D B I x : : M y S e r v e r : : 
  u s e   b a s e   ' C l a s s : : A c c e s s o r : : F a s t ' ; 
  
  _ _ P A C K A G E _ _ - > m k _ a c c e s s o r s ( q w / 
+         u s e r n a m e 
+         p a s s w o r d 
          w h e e l 
          s e s s i o n _ i d 
          s e s s i o n 
@@ -31,6 +33,7 @@ p a c k a g e   P O E : : C o m p o n e n t : : D B I x : : M y S e r v e r : : 
          r o w s _ b u f f e r 
          d a t a b a s e 
          s e r v e r _ c l a s s 
+         w a n t _ d b _ n a m e 
  / ) ; 
  
  u s e   D a t a : : D u m p e r ; 
@@ -194,6 +197,8 @@ p a c k a g e   P O E : : C o m p o n e n t : : D B I x : : M y S e r v e r : : 
          
          # p r i n t   "     ' " . $ d a t a . " '     \ n " ; 
          
+         m y   $ d a t a b a s e ; 
+ 
          m y   $ p t r   =   0 ; 
          m y   $ h e a d e r _ f l a g s   =   s u b s t r ( $ d a t a ,   $ p t r ,   4 ) ; 
          $ p t r   =   $ p t r   +   4 ; 
@@ -226,22 +231,82 @@ p a c k a g e   P O E : : C o m p o n e n t : : D B I x : : M y S e r v e r : : 
                  $ p t r   =   $ p t r   +   $ s c r a m b l e _ l e n g t h ; 
                  } 
                  
-                 m y   $ d a t a b a s e ; 
-                 
                  m y   $ d a t a b a s e _ e n d   =   i n d e x (   $ d a t a ,   " \ 0 " ,   $ p t r ) ; 
                  i f   ( $ d a t a b a s e _ e n d   ! =   - 1   )   { 
                    $ d a t a b a s e   =   s u b s t r ( $ d a t a ,   $ p t r ,   $ d a t a b a s e _ e n d   -   $ p t r ) ; 
                  } 
-                 $ d a t a b a s e   | | =   ' d e f a u l t ' ; 
-                 
+ #                 $ d a t a b a s e   | | =   ' N U L L ' ; 
+               
+   
+                 $ s e l f - > d a t a b a s e ( $ d a t a b a s e ) ; 
+                 $ s e l f - > u s e r n a m e ( $ u s e r n a m e ) ; 
+ #                 $ s e l f - > p a s s w o r d ( $ d a t a b a s e ) ; 
+ 
+ 
                  p r i n t   $ u s e r n a m e ; 
                  p r i n t   '   ~ ~   ' . $ d a t a b a s e . " \ n " ; 
+ 
+                 m y   $ m o d u l e   =   $ s e l f - > s e r v e r _ c l a s s ; 
+ 
+                 u n l e s s   ( C l a s s : : I n s p e c t o r - > l o a d e d ( $ m o d u l e ) )   { 
+                         r e q u i r e   C l a s s : : I n s p e c t o r - > f i l e n a m e ( $ m o d u l e ) ; 
+                 } 
+ 
+                 i f   ( m y   $ c o d e   =   $ m o d u l e - > c a n ( ' c h a n g e _ d b ' ) )   { 
+                         e v a l   {   
+                                 $ c o d e - > ( $ m o d u l e ,   $ s e l f ,   $ d a t a b a s e ) ; 
+                         } ; 
+ 
+                         i f   ( $ @ )   { 
+                                 d i e   $ @ ; 
+                         } 
+ 
+                         u n l e s s   ( $ @ )   { 
+                                 $ s e l f - > d a t a b a s e ( $ d a t a ) ; 
+                         } 
+                 } 
+                 
          } ; 
-         
-         $ s e l f - > a u t h e n t i c a t e d ( 1 ) ; 
-         $ s e l f - > s e n d _ o k ; 
+ 
+         i f   ( $ @ )   { 
+                 d i e   $ @ ; 
+         } 
+ 
+         i f   ( $ d a t a b a s e )   { 
+                 $ s e l f - > a u t h e n t i c a t e d ( 1 ) ; 
+                 $ s e l f - > s e n d _ o k ; 
+         } 
+         e l s e   { 
+               $ s e l f - > s e n d _ e r r o r ( ' P l e a s e   c h o o s e   a   d a t a b a s e   ! ' ) ;   
+         } 
  } 
  
+ 
+ 
+ s u b   s e n d _ e r r o r   { 
+ # # #   S e n d i n g   E r r o r   . . . 
+ 	 m y   ( $ s e l f ,   $ m e s s a g e ,   $ e r r n o ,   $ s q l s t a t e )   =   @ _ ; 
+ # # # #   $ e r r n o 
+ # # # #   $ s q l s t a t e 
+ # # # #   $ m e s s a g e 
+ 	 #   h t t p : / / d e v . m y s q l . c o m / d o c / i n t e r n a l s / e n / e r r o r - p a c k e t . h t m l 
+ 
+ 	 $ m e s s a g e   =   ' U n k n o w n   M y S Q L   e r r o r '   i f   n o t   d e f i n e d   $ m e s s a g e ; 
+ 	 $ e r r n o   =   2 0 0 0   i f   n o t   d e f i n e d   $ e r r n o ; 
+ 	 $ s q l s t a t e   =   ' H Y 0 0 0 '   i f   n o t   d e f i n e d   $ s q l s t a t e ; 
+ 
+ 	 m y   $ p a y l o a d   =   c h r ( 0 x f f ) ; 	 	 #   f i e l d _ c o u n t ,   a l w a y s   =   0 x f f 
+ 	 $ p a y l o a d   . =   p a c k ( ' v ' ,   $ e r r n o ) ; 
+ 	 $ p a y l o a d   . =   ' # ' ; 	 	 	 	 #   s q l s t a t e   m a r k e r ,   a l w a y s   # 
+ 	 $ p a y l o a d   . =   $ s q l s t a t e ; 
+ 	 $ p a y l o a d   . =   $ m e s s a g e . " \ 0 " ; 
+ 
+ 
+         $ s e l f - > w r i t e (   $ p a y l o a d ,   1 ) ; 
+ 
+ } 
+ 
+ 
    
  # s u b   r e s o l v e _ q u e r y   { 
  #         m y   ( $ s e l f ,   $ q u e r y )   =   @ _ ; 
@@ -278,6 +343,9 @@ p a c k a g e   P O E : : C o m p o n e n t : : D B I x : : M y S e r v e r : : 
          e l s i f   ( $ q u e r y   = ~   / d a t a b a s e s / )   { 
                  r e t u r n   ' t e s t _ d b ' ; 
          } 
+         e l s i f   ( $ q u e r y   e q   ' s h o w   t a b l e s ' )   { 
+                 r e t u r n   ' s h o w _ t a b l e s ' ; 
+         } 
          e l s i f   ( $ q u e r y   = ~   / ^ s e l e c t   d a t a b a s e / i )   { 
                  r e t u r n   ' s e l e c t _ d b ' ; 
          } 
@@ -344,18 +412,26 @@ p a c k a g e   P O E : : C o m p o n e n t : : D B I x : : M y S e r v e r : : 
  
                  m y   $ e v e n t ; 
  
-                 e v a l   { 
-                         $ e v e n t   =   $ s e l f - > r e s o l v e _ q u e r y ( $ d a t a ) ; 
+                 $ e v e n t   =   $ s e l f - > r e s o l v e _ s y s _ q u e r y ( $ d a t a ) ; 
+ 
+                 u n l e s s   ( $ e v e n t )   { 
+ 
+                         e v a l   { 
+                                 $ e v e n t   =   $ s e l f - > r e s o l v e _ q u e r y ( $ d a t a ) ; 
+                         } ; 
+ 
+                         i f   ( $ @ )   { 
+                                 p r i n t   $ @ . " \ n " ; 
+                                 $ e v e n t   =   $ s e l f - > r e s o l v e _ s y s _ q u e r y ( $ d a t a ) ; 
+                         } 
+                     
+                         i f   ( $ s e l f - > w a n t _ d b _ n a m e )   { 
+                 #                         p r i n t   " q u e r y   i s   D B   n a m e   ! !   \ n " ; 
+                                 $ e v e n t   =   ' s e l e c t _ d b ' ; 
+                         } 
                  } ; 
+                 p r i n t   " f i r i n g   q u e r y   i s   $ d a t a   /   $ e v e n t   \ n " ; 
  
-                 i f   ( $ @ )   { 
-                         $ e v e n t   =   $ s e l f - > r e s o l v e _ s y s _ q u e r y ( $ d a t a ) ; 
-                 } 
- 
-                 p r i n t   " f i r i n g   q u e r y   i s   $ d a t a   \ n " ; 
-               
-             
-   
                  P O E : : K e r n e l - > p o s t ( 
                          $ s e l f - > s e s s i o n _ i d ,   
                          $ e v e n t ,   
@@ -539,7 +615,8 @@ p a c k a g e   P O E : : C o m p o n e n t : : D B I x : : M y S e r v e r : : 
          $ p a y l o a d   . =   $ s e l f - > b a n n e r ; 
          $ p a y l o a d   . =   p a c k ( ' V ' ,   $ s e l f - > t i d ) ; 
          $ p a y l o a d   . =   s u b s t r ( $ s e l f - > s a l t , 0 , 8 ) . " \ 0 " ; 
-         $ p a y l o a d   . =   p a c k ( ' v ' ,   C L I E N T _ L O N G _ P A S S W O R D   |   C L I E N T _ C O N N E C T _ W I T H _ D B   |   C L I E N T _ P R O T O C O L _ 4 1   |   C L I E N T _ S E C U R E _ C O N N E C T I O N ) ; 
+ #         $ p a y l o a d   . =   p a c k ( ' v ' ,   C L I E N T _ L O N G _ P A S S W O R D   |   C L I E N T _ C O N N E C T _ W I T H _ D B   |   C L I E N T _ P R O T O C O L _ 4 1   |   C L I E N T _ S E C U R E _ C O N N E C T I O N ) ; 
+         $ p a y l o a d   . =   p a c k ( ' v ' ,   C L I E N T _ C O N N E C T _ W I T H _ D B   |   C L I E N T _ P R O T O C O L _ 4 1   |   C L I E N T _ S E C U R E _ C O N N E C T I O N ) ; 
          $ p a y l o a d   . =   $ s e l f - > c h a r s e t ; 
          $ p a y l o a d   . =   p a c k ( ' v ' ,   S E R V E R _ S T A T U S _ A U T O C O M M I T ) ; 
          $ p a y l o a d   . =   " \ 0 "   x   1 3 ; 
@@ -638,39 +715,49 @@ p a c k a g e   P O E : : C o m p o n e n t : : D B I x : : M y S e r v e r : : 
  
  } 
  
- s u b   c h a n g e _ d b   { 
+ 
+ s u b   s h o w _ t a b l e s   { 
          m y   (   $ k e r n e l ,   $ s e s s i o n ,   $ h e a p ,   $ s e l f   )   =   @ _ [   K E R N E L ,   S E S S I O N ,   H E A P ,   O B J E C T ] ; 
          m y   $ d a t a   =   $ _ [ A R G 0 ] ; 
  
-         #   
-         #   m o d u l e   l o a d   a n d   s h i t   . . . 
-         # 
-         m y   $ m o d u l e   =   $ s e l f - > s e r v e r _ c l a s s ; 
- #         p r i n t   ( $ p a c k a g e . " - > c h a n g e _ d b ( " . $ d a t a . " ) " ) ; 
- 
-         u n l e s s   ( C l a s s : : I n s p e c t o r - > l o a d e d ( $ m o d u l e ) )   { 
-                 r e q u i r e   C l a s s : : I n s p e c t o r - > f i l e n a m e ( $ m o d u l e ) ; 
-         } 
- 
-         i f   ( m y   $ c o d e   =   $ m o d u l e - > c a n ( ' c h a n g e _ d b ' ) )   { 
-                 $ c o d e - > ( $ m o d u l e ,   $ s e l f ,   $ d a t a ) ;   
-         } 
- 
- # 
- #                 P O E : : K e r n e l - > p o s t ( 
- #                         $ s e l f - > s e s s i o n _ i d ,   
- #                         ' a _ d u m m y _ q u e r y ' ,   
- #                         $ d a t a 
- #                 ) ; 
- 
-         
- 
- #         e v a l   ( $ p a c k a g e . " - > c h a n g e _ d b ( " . $ d a t a . " ) " ) ; 
- 
-         p r i n t   ' c h a n g e   d b   ' . $ d a t a . "   o k   ! ! \ n " ; 
+         $ s e l f - > s e n d _ r e s u l t s ( [ ' T a b l e s _ i n _ t e s t d b ' ] , 
+                 [ ] ) ;       	 
  
  } 
  
+ # s u b   c h a n g e _ d b   { 
+ #         m y   (   $ k e r n e l ,   $ s e s s i o n ,   $ h e a p ,   $ s e l f   )   =   @ _ [   K E R N E L ,   S E S S I O N ,   H E A P ,   O B J E C T ] ; 
+ #         m y   $ d a t a   =   $ _ [ A R G 0 ] ; 
+ # 
+ #         #   
+ #         #   m o d u l e   l o a d   a n d   s h i t   . . . 
+ #         # 
+ #         m y   $ m o d u l e   =   $ s e l f - > s e r v e r _ c l a s s ; 
+ # #         p r i n t   ( $ p a c k a g e . " - > c h a n g e _ d b ( " . $ d a t a . " ) " ) ; 
+ # 
+ #         u n l e s s   ( C l a s s : : I n s p e c t o r - > l o a d e d ( $ m o d u l e ) )   { 
+ #                 r e q u i r e   C l a s s : : I n s p e c t o r - > f i l e n a m e ( $ m o d u l e ) ; 
+ #         } 
+ # 
+ #         i f   ( m y   $ c o d e   =   $ m o d u l e - > c a n ( ' c h a n g e _ d b ' ) )   { 
+ #                 $ c o d e - > ( $ m o d u l e ,   $ s e l f ,   $ d a t a ) ;   
+ #         } 
+ # 
+ # # 
+ # #                 P O E : : K e r n e l - > p o s t ( 
+ # #                         $ s e l f - > s e s s i o n _ i d ,   
+ # #                         ' a _ d u m m y _ q u e r y ' ,   
+ # #                         $ d a t a 
+ # #                 ) ; 
+ # 
+ #         
+ # 
+ # #         e v a l   ( $ p a c k a g e . " - > c h a n g e _ d b ( " . $ d a t a . " ) " ) ; 
+ # 
+ #         p r i n t   ' c h a n g e   d b   ' . $ d a t a . "   o k   ! ! \ n " ; 
+ # 
+ # } 
+ 
  s u b   s e l e c t _ d b   { 
          m y   (   $ k e r n e l ,   $ s e s s i o n ,   $ h e a p ,   $ s e l f   )   =   @ _ [   K E R N E L ,   S E S S I O N ,   H E A P ,   O B J E C T ] ; 
          m y   $ d a t a   =   $ _ [ A R G 0 ] ; 
@@ -684,36 +771,66 @@ p a c k a g e   P O E : : C o m p o n e n t : : D B I x : : M y S e r v e r : : 
          m y   $ m o d u l e   =   $ s e l f - > s e r v e r _ c l a s s ; 
  #         p r i n t   ( $ p a c k a g e . " - > c h a n g e _ d b ( " . $ d a t a . " ) " ) ; 
  
-         u n l e s s   ( C l a s s : : I n s p e c t o r - > l o a d e d ( $ m o d u l e ) )   { 
-                 r e q u i r e   C l a s s : : I n s p e c t o r - > f i l e n a m e ( $ m o d u l e ) ; 
-         } 
- 
-         i f   ( m y   $ c o d e   =   $ m o d u l e - > c a n ( ' c h a n g e _ d b ' ) )   { 
-                 $ c o d e - > ( $ m o d u l e ,   $ s e l f ,   $ d a t a ) ;   
-         } 
- 
-       	     p r i n t   " s e l e c t   D B   \ n " ; 
+       	     p r i n t   " s e l e c t   D B   $ d a t a   \ n " ; 
        	 
-             $ s e l f - > s e n d _ r e s u l t s ( [ n e w _ d e f i n i t i o n (   n a m e   = >   ' D a t a b a s e '   ) ] , 
-                 [ [ ' t e s t d b ' ] ] ) ;   	 
+         i f   ( $ d a t a   = ~   / \ ( \ ) / )   { 
+                 $ s e l f - > w a n t _ d b _ n a m e ( 1 ) ; 
+                 p r i n t   " I   w a n t   t h e   n a m e   o f   t h e   d b   \ n " ; 
+                 $ d a t a   =   ' t e s t d b ' ; 
  
-             p r i n t   " d a   D B   w a s   s e n t   . . .   \ n " ; 
+ #                 $ s e l f - > s e n d _ r e s u l t s ( [ ' D a t a b a s e ' ] ,   [ [ ' t e s t d b ' ] ] ) ;   
+                 $ s e l f - > s e n d _ r e s u l t s ( [ ' d a t a b a s e ( ) ' ] ,   [ [ $ s e l f - > d a t a b a s e ] ] ) ;   
  
+         } 
+         e l s e   { 
+ 
+                 $ s e l f - > w a n t _ d b _ n a m e ( 0 ) ; 
+ 
+                 u n l e s s   ( C l a s s : : I n s p e c t o r - > l o a d e d ( $ m o d u l e ) )   { 
+                         r e q u i r e   C l a s s : : I n s p e c t o r - > f i l e n a m e ( $ m o d u l e ) ; 
+                 } 
+ 
+                 i f   ( m y   $ c o d e   =   $ m o d u l e - > c a n ( ' c h a n g e _ d b ' ) )   { 
+                         e v a l   {   
+                                 $ c o d e - > ( $ m o d u l e ,   $ s e l f ,   $ d a t a ) ; 
+                         } ; 
+ 
+                         u n l e s s   ( $ @ )   { 
+                                 $ s e l f - > d a t a b a s e ( $ d a t a ) ; 
+                         } 
+                 } 
+ 
+                 
+ 
+     p r i n t   " d a   " . $ d a t a . "   D B   w a s   s e n t   . . .   \ n " ; 
+                 $ s e l f - > s e n d _ r e s u l t s ( [ n e w _ d e f i n i t i o n (   n a m e   = >   ' D a t a b a s e '   ) ] ,   [ [ $ d a t a ] ] ) ;   	 
+ 
+         } 
+ 
+ 
+ #         $ d a t a   | | =   ' t e s t d b ' ; 
+ 
+ 
+ #             $ s e l f - > s e n d _ r e s u l t s ( [ n e w _ d e f i n i t i o n (   n a m e   = >   ' D a t a b a s e '   ) ] , 
+ #                 [ [ ' t e s t d b ' ] , [ ' m y d b ' ] , [ ' D a t a b a s e T e s t ' ] , [ ' t e s t d b ' ] ] ) ;   	 
+ 
+     
+ 
+ #         $ s e l f - > s e n d _ r e s u l t s ( [ n e w _ d e f i n i t i o n (   n a m e   = >   ' D a t a b a s e '   ) ] , [ [ ' t e s t d b ' ] ] ) ;   	 
+ 
+ 
+         
  
  } 
  s u b   t e s t _ d b   { 
          m y   (   $ k e r n e l ,   $ s e s s i o n ,   $ h e a p ,   $ s e l f   )   =   @ _ [   K E R N E L ,   S E S S I O N ,   H E A P ,   O B J E C T ] ; 
          m y   $ d a t a   =   $ _ [ A R G 0 ] ; 
  
-         p r i n t   ' t e s t   ~   s e s s i o n   I D   =   ' . $ s e s s i o n - > I D . " \ n " ; 
        
-       	     p r i n t   " v e r s i o n _ c o m m e n t   ! !   \ n " ; 
+         p r i n t   " s h o w   d a t a b a s e s   ! !   \ n " ; 
        	 
-             $ s e l f - > s e n d _ r e s u l t s ( [ n e w _ d e f i n i t i o n (   n a m e   = >   ' D a t a b a s e '   ) ] , 
-                 [ [ ' m y d b ' ] , [ ' t e s t d b ' ] ] ) ;   	 
- 
-             p r i n t   " d a   D B   w a s   s e n t   . . .   \ n " ; 
- 
+         $ s e l f - > s e n d _ r e s u l t s ( [ n e w _ d e f i n i t i o n (   n a m e   = >   ' D a t a b a s e '   ) ] , 
+                 [ [ ' m y d b ' ] , [ ' D a t a b a s e T e s t ' ] , [ ' t e s t d b ' ] ] ) ;   	 
  
  } 
  
